#!/bin/sh
#/****************************************************************************/
#/* IPTABLES SETUP SCRIPT for Management LAN                                 */
#/*                                          Copyright FUJITSU LTD 2009      */
#/*                                                                          */
#/* $Name: SLINPSA-2_8_1-0 $                                                     */
#/****************************************************************************/
# Development date : Fri OCT 16 2009

#==============================================================================
# This is the script to set the firewall for management LAN.
# Only root user is permitted to execute this script.
# This script will return as follows.
#      0 : End successfully
#      1 : Abnormal end
#==============================================================================

REGEX="^([[:digit:]]+\.){3}[[:digit:]]+($|/[[:digit:]]+$)"
IPSETCONF="/etc/opt/FJSVpsa/usr/ipsetup.conf"

if [ $# -ne 1 ]
    then
    echo "Too few or more argument"
    echo "Usage: setmlanfw.sh <configure_file>"
    exit 1
fi

if [ ! -f $1 ]
    then
    echo "Cannot read the file : $1"
    exit 1
fi
TABLECONF=$1

if [ ! -f $IPSETCONF ]
    then
    echo "Cannot read the file : $IPSETCONF"
    exit 1
fi

/sbin/service iptables status > /dev/null 2>&1

if [ $? -ne 0 ]
then
    echo ""
    echo "#########################################################################################"
    echo "# setmlanfw.sh couldn't set iptables setting. because iptables service has been stopped.#"
    echo "# Please set iptables setting by manual.                                                #"
    echo "# For more detail on how to set iptables setting, refer to the Installation Manual.     #"
    echo "#########################################################################################"
    echo ""
    exit 1
fi

## Read IPSETCONF
flg=0
while read LINE
  do
  if [ $flg == 0 ]
      then
      echo $LINE|egrep "^ *\[ *NETWORK *\]" >/dev/null
      eff=$?
      if [ $eff == 0 ]
	  then
	  flg=1
      fi
  else
      echo $LINE|egrep "^ *\[.*\]" >/dev/null
      eff=$?
      if [ $eff == 0 ]
	  then
	  flg=0
      fi
      echo $LINE|egrep "^ *ManagementIP *="|grep -v "^\;" >/dev/null
      eff=$?
      if [ $eff == 0 ]
	  then
	  MMIP=$(echo $LINE|cut -d"=" -f 2|tr -d ' ')
	  echo $MMIP|egrep "$REGEX" >/dev/null
	  eff=$?
	  if [ $eff == 0 ]
	      then
	      break
	  else
	      echo "No IP setting or illegal IP format in $IPSETCONF"
	      exit 1
	  fi
      fi
  fi
done < $IPSETCONF
if [ -x $MMIP ]
    then
    echo "No IP setting in $IPSETCONF"
fi

## Read Userfile
flg=0
MMB_NUM=0
while read LINE
  do
  if [ $flg == 0 ]
      then
      echo $LINE|egrep "^ *\[ *PCL *\]" >/dev/null
      eff=$?
      if [ $eff == 0 ]
	  then
	  flg=1
      fi
  else
      echo $LINE|egrep "^ *\[.*\]" >/dev/null
      eff=$?
      if [ $eff == 0 ]
	  then
	  flg=0
      fi
      echo $LINE|egrep "$REGEX" >/dev/null
      eff=$?
      if [ $eff == 0 ]
	  then
	  MIP[$MMB_NUM]=$LINE
	  MMB_NUM=$(expr $MMB_NUM + 1)
      fi
  fi
done < $TABLECONF

##Check IPs
echo "Management LAN IP address:"
echo "$MMIP"
echo
echo "Source IPs for PRIMECLUSTER Service:"
i=0
while [ $i -ne $MMB_NUM ]
  do
  echo "${MIP[$i]}"
  i=$(expr $i + 1)
done
echo
echo "Press \"Y\" to confirm above settings, \"N\" to cancel all settings"
while :
  do
  read -p '>' A
  case "$A" in
      "Y") break;;
      "y") break;;
      "N") exit 1;;
      "n") exit 1;;
      *) echo "Press \"Y\" or \"N\"" ;;
  esac
done

iptables -L MMLAN > /dev/null 2>&1
eff=$?
if [ $eff == 0 ]
    then
    echo "Already set iptables"
    exit 0
fi

iptables -N MMLAN
i=0
while [ $i -ne $MMB_NUM ]
  do

  iptables -A MMLAN -p udp -s ${MIP[$i]} -d ${MMIP} --dport 7000:7100 -j ACCEPT
  iptables -A MMLAN -p udp -d ${MIP[$i]} -s ${MMIP} --sport 7000:7100 -j ACCEPT
  iptables -A MMLAN -p udp -s ${MIP[$i]} -d ${MMIP} --dport snmptrap -j ACCEPT
  iptables -A MMLAN -p udp -d ${MIP[$i]} -s ${MMIP} --sport snmptrap -j ACCEPT
  i=$(expr $i + 1)

done

echo ""
echo "############################################################################"
echo "# Created the MMLAN chain on your firewall(iptables).                      #"
echo "# For more detail on how to set firewall, refer to the Installation Manual.#"
echo "############################################################################"
echo ""

/sbin/service iptables save > /dev/null 2>&1

echo "The setting was completed"
exit 0
